@@ -1,4 +1,4 @@
-import collections
+from collections.abc import Iterable
 import traceback
 
 
@@ -11,7 +11,7 @@ def ex_to_str(ex):
 def unfold(iterable, max_level=None, curr_level=1):
     ret = []
     for element in iterable:
-        if isinstance(element, collections.Iterable) and (max_level is None or curr_level < max_level):
+        if isinstance(element, Iterable) and (max_level is None or curr_level < max_level):
             ret.append(unfold(element, max_level=max_level, curr_level=curr_level + 1))
         else:
             ret.append(element)
